<?php
/*
 * The MIT License
 *
 * Copyright (c) 2017-2020 Neotrendy s. r. o. (www.neotrendy.com), Trust Pay, a. s. (www.trustpay.eu)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/**
 * Class ModelExtensionPaymentTrustPayCP
 *
 * The OpenCart extension for TrustPay payment gateway API v2.
 * Card payments.
 * Catalog model.
 * https://doc.trustpay.eu/v02
 *
 * @copyright  2019 Trust Pay, a. s.
 * @author     Neotrendy s. r. o.
 * @link       https://bitbucket.org/Neotrendy/trustpay/
 */
class ModelExtensionPaymentTrustPayCP extends Model {
	public function getMethod($address, $total) {
		$this->load->language('extension/payment/trustpay_cp');

		$query = $this->db->query("SELECT * FROM " . DB_PREFIX . "zone_to_geo_zone WHERE geo_zone_id = '" . (int)$this->config->get('trustpay_cp_geo_zone_id') . "' AND country_id = '" . (int)$address['country_id'] . "' AND (zone_id = '" . (int)$address['zone_id'] . "' OR zone_id = '0')");

		if ($this->config->get('trustpay_cp_total') > $total) {
			$status = false;
		} elseif (!$this->config->get('trustpay_cp_geo_zone_id')) {
			$status = true;
		} elseif ($query->num_rows) {
			$status = true;
		} else {
			$status = false;
		}

        if ($this->config->get('trustpay_cp_test') && $this->session->data['currency'] != 'EUR') {
            $status = false;
        }

		$method_data = array();

		if ($status) {
			$method_data = array(
				'code'       => 'trustpay_cp',
				'title'      => $this->language->get('text_title'),
				'terms'      => '',
				'sort_order' => $this->config->get('trustpay_cp_sort_order')
			);
		}

		return $method_data;
	}
}
